// Copyright 2019 The Gitea Authors. All rights reserved.
// Use of this source code is governed by a MIT-style
// license that can be found in the LICENSE file.

package migrations

import (
	"fmt"

	"code.gitea.io/gitea/modules/timeutil"
	"xorm.io/xorm"
)

func addDatasetTable(x *xorm.Engine) error {
	type Dataset struct {
		ID            int64  `xorm:"pk autoincr"`
		Title         string `xorm:"INDEX NOT NULL"`
		Status        int32  `xorm:"INDEX"`
		Category      string
		Description   string `xorm:"TEXT"`
		DownloadTimes int64
		License       string
		Task          string
		ReleaseID     int64              `xorm:"INDEX"`
		UserID        int64              `xorm:"INDEX"`
		CreatedUnix   timeutil.TimeStamp `xorm:"INDEX created"`
		UpdatedUnix   timeutil.TimeStamp `xorm:"INDEX updated"`
	}

	if err := x.Sync2(new(Dataset)); err != nil {
		return fmt.Errorf("Sync2: %v", err)
	}
	return nil
}
